CLI Docs
========

Installation
------------

You can install the `queenbee` cli tool using the following command::

   pip install -u queenbee[cli]

.. note::
   You might need to add "\\" to escape the "[]" brackets on unix based systems::

      pip install -u queenbee\[cli\]

Commands
------------
.. toctree::
   :maxdepth: 1

   main
   plugin
   recipe
   repository

